abacusai.web_search_response — AbacusAI documentation

# abacusai.web_search_response

## Classes

`WebSearchResponse` | Result of running a web search with optional content fetching.

## Module Contents

class abacusai.web_search_response.WebSearchResponse(client, searchResults={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Result of running a web search with optional content fetching.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - searchResults (WebSearchResult) – List of search results.

  search_results
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict